.eslintrc
.gherkin-lintrc
.gitattributes
.git
.gitignore
.github
.grunt
.jshintignore
.jshintrc
.nvmrc
.shifter.json
.stylelintrc
.travis.yml
CONTRIBUTING.txt
COPYING.txt
Gruntfile.js
INSTALL.txt
PULL_REQUEST_TEMPLATE.txt
README.txt
TRADEMARK.txt
admin
analytics
auth
availability
backup
badges
behat.yml.dist
blocks
blog
brokenfile.php
cache
calendar
cohort
comment
competency
completion
composer.json
composer.lock
config-dist.php
contentbank
course
customfield
dataformat
draftfile.php
editmode.php
enrol
error
favourites
file.php
files
filter
githash.php
grade
group
h5p
help.php
help_ajax.php
index.php
install
install.php
iplookup
lang
lib
local
login
media
message
mnet
mod
my
notes
npm-shrinkwrap.json
package.json
payment
phpcs.xml.dist
phpunit.xml.dist
pix
plagiarism
pluginfile.php
portfolio
privacy
question
rating
report
reportbuilder
repository
rss
search
security.txt
tag
theme
tokenpluginfile.php
user
userpix
version.php
webservice
config.php